Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1170)

Unified Diff: chrome/test/plugin/pdf_browsertest.cc

Issue 7327007: Moving notification types which are chrome specific to a new header file chrome_notification_type... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/live_sync/live_autofill_sync_test.cc ('k') | chrome/test/test_notification_tracker.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/plugin/pdf_browsertest.cc
===================================================================
--- chrome/test/plugin/pdf_browsertest.cc (revision 91968)
+++ chrome/test/plugin/pdf_browsertest.cc (working copy)
@@ -16,8 +16,8 @@
#include "chrome/test/ui_test_utils.h"
#include "content/browser/renderer_host/render_view_host.h"
#include "content/browser/tab_contents/tab_contents.h"
+#include "content/common/content_notification_types.h"
#include "content/common/notification_observer.h"
-#include "content/common/notification_type.h"
#include "net/test/test_server.h"
#include "ui/base/clipboard/clipboard.h"
#include "ui/gfx/codec/png_codec.h"
@@ -81,7 +81,7 @@
TabContentsWrapper* wrapper = browser()->GetSelectedTabContentsWrapper();
wrapper->CaptureSnapshot();
ui_test_utils::RegisterAndWait(this,
- NotificationType::TAB_SNAPSHOT_TAKEN,
+ chrome::TAB_SNAPSHOT_TAKEN,
Source<TabContentsWrapper>(wrapper));
ASSERT_FALSE(snapshot_different_) << "Rendering didn't match, see result "
"at " << snapshot_filename_.value().c_str();
@@ -106,10 +106,10 @@
private:
// NotificationObserver
- virtual void Observe(NotificationType type,
+ virtual void Observe(int type,
const NotificationSource& source,
const NotificationDetails& details) {
- if (type == NotificationType::TAB_SNAPSHOT_TAKEN) {
+ if (type == chrome::TAB_SNAPSHOT_TAKEN) {
MessageLoopForUI::current()->Quit();
FilePath reference = ui_test_utils::GetTestFilePath(
GetPDFTestDir(),
@@ -172,7 +172,7 @@
reinterpret_cast<char*>(&png_data[0]), png_data.size());
}
}
- } else if (type == NotificationType::LOAD_STOP) {
+ } else if (type == chrome::LOAD_STOP) {
load_stop_notification_count_++;
}
}
@@ -185,7 +185,7 @@
std::string expected_filename_;
// If the snapshot is different, holds the location where it's saved.
FilePath snapshot_filename_;
// How many times we've seen NotificationType::LOAD_STOP.
int load_stop_notification_count_;
scoped_ptr<net::TestServer> pdf_test_server_;
@@ -276,7 +276,7 @@
&(browser()->GetSelectedTabContents()->controller());
NotificationRegistrar registrar;
registrar.Add(this,
- NotificationType::LOAD_STOP,
+ chrome::LOAD_STOP,
Source<NavigationController>(controller));
std::string base_url = std::string("files/");
@@ -303,7 +303,7 @@
while (true) {
int last_count = load_stop_notification_count();
// We might get extraneous NotificationType::LOAD_STOP notifications when
// doing async loading. This happens when the first loader is cancelled
// and before creating a byte-range request loader.
bool complete = false;
@@ -185,7 +185,7 @@
// If the snapshot is different, holds the location where it's saved.
FilePath snapshot_filename_;
- // How many times we've seen NotificationType::LOAD_STOP.
+ // How many times we've seen chrome::LOAD_STOP.
int load_stop_notification_count_;
scoped_ptr<net::TestServer> pdf_test_server_;
@@ -303,7 +303,7 @@
while (true) {
int last_count = load_stop_notification_count();
- // We might get extraneous NotificationType::LOAD_STOP notifications when
+ // We might get extraneous chrome::LOAD_STOP notifications when
// doing async loading. This happens when the first loader is cancelled
// and before creating a byte-range request loader.
« no previous file with comments | « chrome/test/live_sync/live_autofill_sync_test.cc ('k') | chrome/test/test_notification_tracker.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698